[![pypi-version]][pypi]

# prf-jsonapi
JSONAPI support for Pyramid Restful Framework


[pypi-version]: https://badge.fury.io/py/pyramid-restful-jsonapi.svg
[pypi]: https://pypi.python.org/pypi/pyramid-restful-jsonapi
